@@ -1,6 +1,8 @@
-import chardet
+#import chardet
 import pkgutil
 import yaml
+from chardet.universaldetector import UniversalDetector
+from io import BytesIO
 
 from header_rewriter import RewrittenStatusAndHeaders
 
@@ -8,7 +10,8 @@ from rewriterules import RewriteRules
 
 from pywb.utils.dsrules import RuleSet
 from pywb.utils.statusandheaders import StatusAndHeaders
-from pywb.utils.bufferedreaders import DecompressingBufferedReader, ChunkedDataReader
+from pywb.utils.bufferedreaders import DecompressingBufferedReader
+from pywb.utils.bufferedreaders import ChunkedDataReader
 
 
 #=================================================================
@@ -18,42 +21,60 @@ class RewriteContent:
                                default_rule_config={},
                                ds_rules_file=ds_rules_file)
 
+    def sanitize_content(self, status_headers, stream):
+        # remove transfer encoding chunked and wrap in a dechunking stream
+        if (status_headers.remove_header('transfer-encoding')):
+            stream = ChunkedDataReader(stream)
+
+        return (status_headers, stream)
+
     def rewrite_headers(self, urlrewriter, status_headers, stream, urlkey=''):
-        header_rewriter_class = self.ruleset.get_first_match(urlkey).rewriters['header']
 
-        rewritten_headers = header_rewriter_class().rewrite(status_headers, urlrewriter)
+        header_rewriter_class = (self.ruleset.get_first_match(urlkey).
+                                 rewriters['header'])
 
-        # note: since chunking may be broken, approach taken here is to *always* attempt
-        # to dechunk if transfer-encoding: chunked is present
+        rewritten_headers = (header_rewriter_class().
+                             rewrite(status_headers, urlrewriter))
+
+        # note: since chunk encoding may/may not be valid,
+        # the approach taken here is to *always* attempt
+        # to dechunk if 'transfer-encoding: chunked' is present
         #
-        # an alternative may be to serve chunked unless content rewriting is needed
+        # an alternative may be to serve chunked unless
+        # content rewriting is needed
         # todo: possible revisit this approach
 
-        if (rewritten_headers.contains_removed_header('transfer-encoding', 'chunked')):
+        if (rewritten_headers.
+             contains_removed_header('transfer-encoding', 'chunked')):
+
             stream = ChunkedDataReader(stream)
 
         return (rewritten_headers, stream)
 
-    def rewrite_content(self, urlrewriter, headers, stream, head_insert_func=None, urlkey=''):
+    def rewrite_content(self, urlrewriter, headers, stream,
+                        head_insert_func=None, urlkey='',
+                        sanitize_only=False):
 
-        # see if we've already rewritten headers
-        if isinstance(headers, RewrittenStatusAndHeaders):
-            rewritten_headers = headers
-        elif isinstance(headers, StatusAndHeaders):
-        # otherwise, need to determine if rewriting is even necessary
-            (rewritten_headers, stream) = self.rewrite_headers(urlrewriter, headers, stream)
-            # no rewriting needed here
-            if rewritten_headers.text_type is None:
-                gen = self.stream_to_gen(stream)
-                return (status_headers, gen)
+        if sanitize_only:
+            status_headers, stream = self.sanitize_content(headers, stream)
+            return (status_headers, self.stream_to_gen(stream), False)
+
+        (rewritten_headers, stream) = self.rewrite_headers(urlrewriter,
+                                                           headers,
+                                                           stream)
 
         status_headers = rewritten_headers.status_headers
 
+        # use rewritten headers, but no further rewriting needed
+        if rewritten_headers.text_type is None:
+            return (status_headers, self.stream_to_gen(stream), False)
+
         # Handle text content rewriting
-        # =========================================================================
+        # ====================================================================
         # special case -- need to ungzip the body
 
-        if (rewritten_headers.contains_removed_header('content-encoding', 'gzip')):
+        if (rewritten_headers.
+             contains_removed_header('content-encoding', 'gzip')):
             stream = DecompressingBufferedReader(stream, decomp_type='gzip')
 
         if rewritten_headers.charset:
@@ -75,9 +96,8 @@ class RewriteContent:
         except KeyError:
             raise Exception('Unknown Text Type for Rewrite: ' + text_type)
 
-        #import sys
-        #sys.stderr.write(str(vars(rule)))
-
+        # for html, need to perform header insert, supply js, css, xml
+        # rewriters
         if text_type == 'html':
             head_insert_str = ''
 
@@ -85,20 +105,22 @@ class RewriteContent:
                 head_insert_str = head_insert_func(rule)
 
             rewriter = rewriter_class(urlrewriter,
-                                      outstream=None,
                                       js_rewriter_class=rule.rewriters['js'],
                                       css_rewriter_class=rule.rewriters['css'],
                                       head_insert=head_insert_str)
         else:
+        # apply one of (js, css, xml) rewriters
             rewriter = rewriter_class(urlrewriter)
 
         # Create rewriting generator
-        gen = self._rewriting_stream_gen(rewriter, encoding, stream, first_buff)
-        return (status_headers, gen)
+        gen = self._rewriting_stream_gen(rewriter, encoding,
+                                         stream, first_buff)
 
+        return (status_headers, gen, True)
 
     # Create rewrite stream,  may even be chunked by front-end
-    def _rewriting_stream_gen(self, rewriter, encoding, stream, first_buff = None):
+    def _rewriting_stream_gen(self, rewriter, encoding,
+                              stream, first_buff=None):
         def do_rewrite(buff):
             if encoding:
                 buff = self._decode_buff(buff, stream, encoding)
@@ -111,12 +133,19 @@ class RewriteContent:
             return buff
 
         def do_finish():
-            return rewriter.close()
+            result = rewriter.close()
+            if encoding:
+                result = result.encode(encoding)
 
-        return self.stream_to_gen(stream, rewrite_func = do_rewrite, final_read_func = do_finish, first_buff = first_buff)
+            return result
 
+        return self.stream_to_gen(stream,
+                                  rewrite_func=do_rewrite,
+                                  final_read_func=do_finish,
+                                  first_buff=first_buff)
 
-    def _decode_buff(self, buff, stream, encoding):
+    @staticmethod
+    def _decode_buff(buff, stream, encoding):
         try:
             buff = buff.decode(encoding)
         except UnicodeDecodeError, e:
@@ -133,17 +162,31 @@ class RewriteContent:
 
         return buff
 
-
     def _detect_charset(self, stream):
-        buff = stream.read(8192)
-        result = chardet.detect(buff)
-        print "chardet result: " + str(result)
-        return (result['encoding'], buff)
+        full_buff = stream.read(8192)
+        io_buff = BytesIO(full_buff)
 
+        detector = UniversalDetector()
 
-    # Create a generator reading from a stream, with optional rewriting and final read call
+        try:
+            buff = io_buff.read(256)
+            while buff:
+                detector.feed(buff)
+                if detector.done:
+                    break
+
+                buff = io_buff.read(256)
+        finally:
+            detector.close()
+
+        print "chardet result: " + str(detector.result)
+        return (detector.result['encoding'], full_buff)
+
+    # Create a generator reading from a stream,
+    # with optional rewriting and final read call
     @staticmethod
-    def stream_to_gen(stream, rewrite_func = None, final_read_func = None, first_buff = None):
+    def stream_to_gen(stream, rewrite_func=None,
+                      final_read_func=None, first_buff=None):
         try:
             buff = first_buff if first_buff else stream.read()
             while buff:
@@ -160,5 +203,3 @@ class RewriteContent:
 
         finally:
             stream.close()
-
-
