@@ -1,10 +1,12 @@
+from pytest import raises
 import webtest
-from pywb.core.pywb_init import create_wb_router
+from pywb.webapp.pywb_init import create_wb_router
 from pywb.framework.wsgi_wrappers import init_app
 from pywb.cdx.cdxobject import CDXObject
 
+
 class TestWb:
-    TEST_CONFIG = 'test_config.yaml'
+    TEST_CONFIG = 'tests/test_config.yaml'
 
     def setup(self):
         #self.app = pywb.wbapp.create_wb_app(pywb.pywb_init.pywb_config())
@@ -38,6 +40,16 @@ class TestWb:
         self._assert_basic_html(resp)
         assert 'Search' in resp.body
 
+    def test_pywb_root_head(self):
+        resp = self.testapp.head('/pywb/')
+        assert resp.content_type == 'text/html'
+        assert resp.status_int == 200
+
+    def test_pywb_invalid_path(self):
+        resp = self.testapp.head('/blah/', status=404)
+        assert resp.content_type == 'text/html'
+        assert resp.status_int == 404
+
     def test_calendar_query(self):
         resp = self.testapp.get('/pywb/*/iana.org')
         self._assert_basic_html(resp)
@@ -91,11 +103,35 @@ class TestWb:
         assert 'wb.js' in resp.body
         assert '/pywb/20130729195151/http://www.iana.org/domains/example"' in resp.body
 
+    def test_replay_cdx_mod(self):
+        resp = self.testapp.get('/pywb/20140127171239cdx_/http://www.iana.org/_css/2013.1/print.css')
+        self._assert_basic_text(resp)
+
+        lines = resp.body.rstrip().split('\n')
+        assert len(lines) == 17
+        assert lines[0].startswith('org,iana)/_css/2013.1/print.css 20140127171239')
+
+
     def test_replay_identity_1(self):
         resp = self.testapp.get('/pywb/20140127171251id_/http://example.com')
-        #resp = self.testapp.get('/pywb/20140126200654id_/http://www.iana.org/_img/2013.1/rir-map.svg')
-        #resp = self.testapp.get('/pywb/20140127171239id_/http://www.iana.org/_css/2013.1/screen.css')
-        #self._assert_basic_html(resp)
+
+        # no wb header insertion
+        assert 'wb.js' not in resp.body
+
+        # original unrewritten url present
+        assert '"http://www.iana.org/domains/example"' in resp.body
+
+    def test_replay_identity_2_arcgz(self):
+        resp = self.testapp.get('/pywb/20140216050221id_/http://arc.gz.test.example.com')
+
+        # no wb header insertion
+        assert 'wb.js' not in resp.body
+
+        # original unrewritten url present
+        assert '"http://www.iana.org/domains/example"' in resp.body
+
+    def test_replay_identity_2_arc(self):
+        resp = self.testapp.get('/pywb/20140216050221id_/http://arc.test.example.com')
 
         # no wb header insertion
         assert 'wb.js' not in resp.body
@@ -222,3 +258,10 @@ class TestWb:
         assert resp.status_int == 400
         assert 'Invalid Url: http://?abc' in resp.body
 
+    def test_invalid_config(self):
+        with raises(IOError):
+            init_app(create_wb_router,
+                     load_yaml=True,
+                     config_file='x-invalid-x')
+
+
